adaptive_core library
Adaptive Core Flutter Plugin
Flutter plugin for the Adaptive SDK Core module. Provides SDK initialization, user management, and HTTP client functionality.
Classes
- AdaptiveCore
- The main entry point for the Adaptive Core SDK.
- AdaptiveUser
- Represents an authenticated user in the Adaptive SDK.
Enums
- UserGender
- Represents the gender of a user in the Adaptive SDK.
- UserGrade
- Represents the school grade of a user in the Adaptive SDK.
- UserSchool
- Represents the school type of a user in the Adaptive SDK.
Exceptions / Errors
- AdaptiveException
- Thrown when the Adaptive SDK encounters a platform-level error.